@@ -21,7 +21,7 @@ use base qw( Test::Builder::Module );
 use Carp qw( croak );
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -371,6 +371,17 @@ sub create_cluster_ok
   $tb->ok(@errors == 0, "created cluster");
   $tb->diag("exception: " . $_->[0] . ': ' . $_->[1]) for @errors;
   
+  if($INC{'Clustericious/App.pm'})
+  {
+    eval { require Clustericious::Client };
+    if(!$@ && Clustericious::Client->can('_mojo_user_agent_factory'))
+    {
+      Clustericious::Client->_mojo_user_agent_factory(sub {
+        $self->create_ua;
+      });
+    }
+  }
+  
   return $self;
 }
 
@@ -532,7 +543,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
